@@ -11,7 +11,7 @@ TestingKBlocksWin::TestingKBlocksWin(
     GameLogicInterface *p,
     GraphicsInterface *graphics,
     SoundInterface *sound,
-    KgThemeProvider *themeProvider,
+    KGameThemeProvider *themeProvider,
     KBlocksPlayManager *pM,
     int capacity,
     int gamecount
